@@ -33,8 +33,8 @@ _js_dist = [
     {
         'relative_package_path': 'deckglplotly.min.js',
         'dev_package_path': 'deckglplotly.dev.js',
-        'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
-            package_name, __name__, __version__),
+        # 'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
+        #     package_name, __name__, __version__),
         'namespace': package_name
     }
 ]
